#[repr(C)]pub struct Unit {}Trait Implementations
Sourceimpl CompatFrom<Unit> for Unit
impl CompatFrom<Unit> for Unit
Sourcefn compat_from(value: Unit) -> Self
fn compat_from(value: Unit) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<Unit> for Unit
impl CompatFrom<Unit> for Unit
Sourcefn compat_from(value: Unit) -> Self
fn compat_from(value: Unit) -> Self
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<Unit, ___E> for &'a Unitwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Unit, ___E> for &'a Unitwhere
___E: InternalHandleEncoder + ?Sized,
Sourceimpl<___E> Encode<Unit, ___E> for Unitwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Unit, ___E> for Unitwhere
___E: InternalHandleEncoder + ?Sized,
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Unit>, ___E> for &'a Unit
impl<'a, ___E> EncodeOption<Box<'static, Unit>, ___E> for &'a Unit
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Unit>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Unit>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Unit>, ___E> for Unit
impl<___E> EncodeOption<Box<'static, Unit>, ___E> for Unit
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Unit>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Unit>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWireRef<Unit> for Unit
impl FromWireRef<Unit> for Unit
Sourcefn from_wire_ref(wire: &Unit) -> Self
fn from_wire_ref(wire: &Unit) -> Self
Converts the given reference to this type.
Sourceimpl Ord for Unit
impl Ord for Unit
Sourceimpl PartialOrd for Unit
impl PartialOrd for Unit
impl Copy for Unit
impl Eq for Unit
impl StructuralPartialEq for Unit